@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.70';
+our $VERSION = '0.71';
 
 use Dist::Zilla 6.0;
 
@@ -56,8 +56,6 @@ use Dist::Zilla::Plugin::Test::Compile;
 use Dist::Zilla::Plugin::Test::EOL 0.14;
 use Dist::Zilla::Plugin::Test::NoTabs;
 use Dist::Zilla::Plugin::Test::Pod::Coverage::Configurable;
-use Dist::Zilla::Plugin::Test::Pod::LinkCheck;
-use Dist::Zilla::Plugin::Test::Pod::No404s;
 use Dist::Zilla::Plugin::Test::PodSpelling;
 use Dist::Zilla::Plugin::Test::Portability;
 use Dist::Zilla::Plugin::Test::ReportPrereqs;
@@ -297,6 +295,27 @@ sub _gather_dir_plugin {
     ];
 }
 
+sub _build_exclude {
+    my $self = shift;
+
+    my @filenames = @{ $self->_files_to_copy_from_build };
+
+    my @match;
+    for my $exclude ( @{ $self->exclude_files } ) {
+        if ( $exclude =~ m{^[\w\-\./]+$} ) {
+            push @filenames, $exclude;
+        }
+        else {
+            push @match, qr/$exclude/;
+        }
+    }
+
+    return {
+        filenames => \@filenames,
+        match     => \@match,
+    };
+}
+
 sub _basic_plugins {
 
     # These are a subset of the @Basic bundle except for CheckVersionIncrement
@@ -338,27 +357,6 @@ sub _auto_prereqs_plugin {
     ];
 }
 
-sub _build_exclude {
-    my $self = shift;
-
-    my @filenames = @{ $self->_files_to_copy_from_build };
-
-    my @match;
-    for my $exclude ( @{ $self->exclude_files } ) {
-        if ( $exclude =~ m{^[\w\-\./]+$} ) {
-            push @filenames, $exclude;
-        }
-        else {
-            push @match, qr/$exclude/;
-        }
-    }
-
-    return {
-        filenames => \@filenames,
-        match     => \@match,
-    };
-}
-
 sub _copy_files_from_build_plugin {
     my $self = shift;
 
@@ -401,20 +399,6 @@ sub _github_plugins {
     );
 }
 
-sub _build_allow_dirty {
-    my $self = shift;
-
-    # Anything we auto-generate and check in could be dirty. We also allow any
-    # other file which might get munged by this bundle to be dirty.
-    return [
-        @{ $self->_exclude_filenames },
-        qw(
-            Changes
-            tidyall.ini
-            )
-    ];
-}
-
 sub _meta_plugins {
     my $self = shift;
 
@@ -422,10 +406,10 @@ sub _meta_plugins {
         [ MetaResources           => $self->_meta_resources, ],
         [ 'MetaProvides::Package' => { meta_noindex => 1 } ],
         qw(
-            MetaYAML
             Meta::Contributors
             MetaConfig
             MetaJSON
+            MetaYAML
             ),
     );
 }
@@ -500,16 +484,14 @@ sub _explicit_prereq_plugins {
                 'Test::Vars'                        => '0.009',
             }
         ],
-
-        # This is solely to work around a bug with Test::Version and
-        # Module::Metadata 1.000019 - see
-        # https://github.com/plicease/Test-Version/issues/7 for details.
         [
-            'Prereqs' => 'Module::Metadata 1.000033 for Test::Version' => {
-                -phase             => 'develop',
-                -type              => 'requires',
-                'Module::Metadata' => '1.000033',
-            },
+            'Prereqs' =>
+                'Test::Version which fixes https://github.com/plicease/Test-Version/issues/7'
+                => {
+                -phase          => 'develop',
+                -type           => 'requires',
+                'Test::Version' => '2.05',
+                },
         ],
     );
 }
@@ -585,14 +567,6 @@ sub _pod_test_plugins {
             'Test::PodSpelling' => { stopwords => $self->_all_stopwords },
         ],
         'PodSyntaxTests',
-        (
-            $ENV{TRAVIS} ? () : (
-                qw(
-                    Test::Pod::LinkCheck
-                    Test::Pod::No404s
-                    )
-            )
-        ),
     );
 }
 
@@ -625,13 +599,6 @@ sub _default_stopwords {
     );
 }
 
-sub _contributors_plugins {
-    qw(
-        DROLSKY::Contributors
-        Git::Contributors
-    );
-}
-
 sub _extra_test_plugins {
     return (
         qw(
@@ -659,6 +626,13 @@ sub _extra_test_plugins {
     );
 }
 
+sub _contributors_plugins {
+    qw(
+        DROLSKY::Contributors
+        Git::Contributors
+    );
+}
+
 sub _pod_weaver_plugin {
     return (
         [
@@ -685,8 +659,8 @@ sub _contributing_md_plugin {
     my $self = shift;
 
     return [
-        'GenerateFile::FromShareDir' => 'generate CONTRIBUTING' => {
-            -dist     => 'Dist-Zilla-PluginBundle-DROLSKY',
+        'GenerateFile::FromShareDir' => 'Generate CONTRIBUTING.md' => {
+            -dist     => ( __PACKAGE__ =~ s/::/-/gr ),
             -filename => 'CONTRIBUTING.md',
             has_xs    => $self->_has_xs,
         },
@@ -724,7 +698,7 @@ sub _git_plugins {
 
         # Commit all the dirty files before the release.
         [
-            'Git::Commit' => 'commit generated files' => {
+            'Git::Commit' => 'Commit generated files' => {
                 allow_dirty => $self->_allow_dirty,
             },
         ],
@@ -740,17 +714,31 @@ sub _git_plugins {
 
         # Make another commit with just the version bump.
         [
-            'Git::Commit' => 'commit version bump' => {
+            'Git::Commit' => 'Commit version bump' => {
                 allow_dirty_match => ['.+'],
                 commit_msg        => 'Bump version after release'
             },
         ],
 
         # Push the version bump commit.
-        [ 'Git::Push' => 'push version bump' ],
+        [ 'Git::Push' => 'Push version bump' ],
     );
 }
 
+sub _build_allow_dirty {
+    my $self = shift;
+
+    # Anything we auto-generate and check in could be dirty. We also allow any
+    # other file which might get munged by this bundle to be dirty.
+    return [
+        @{ $self->_exclude_filenames },
+        qw(
+            Changes
+            tidyall.ini
+            )
+    ];
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -769,7 +757,39 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.70
+version 0.71
+
+=head1 SYNOPSIS
+
+    name    = My-Module
+    author  = Dave Rolsky <autarch@urth.org>
+    license = Artistic_2_0
+    copyright_holder = Dave Rolsky
+
+    [@DROLSKY]
+    dist = My-Module
+    ; Fefault is MakeMaker - or set it to ModuleBuild
+    make_tool = MakeMaker
+    ; These files won't be added to tarball
+    exclude_files = ...
+    ; Default is DROLSKY
+    authority = DROLSKY
+    ; Passed to AutoPrereqs - can be repeated
+    prereqs_skkip = ...
+    ; Passed to Test::Pod::Coverage::Configurable if set
+    pod_coverage_class = ...
+    ; Oassed to Test::Pod::Coverage::Configurable if set - can be repeated
+    pod_coverage_skip = ...
+    ; Passed to Test::Pod::Coverage::Configurable if set - can be repeated
+    pod_coverage_trustme = ...
+    ; For pod spelling test - can be repeated
+    stopwords = ...
+    ; Can also put them in a separate file
+    stopwords_file = ..
+    ; Defaults to false
+    use_github_homepage = 0
+    ; Defaults to false
+    use_github_issues = 0
 
 =head1 DESCRIPTION
 
@@ -777,6 +797,236 @@ This is the L<Dist::Zilla> plugin bundle I use for my distributions. Don't use
 this directly for your own distributions, but you may find it useful as a
 source of ideas for building your own bundle.
 
+This bundle uses L<Dist::Zilla::Role::PluginBundle::PluginRemover> and
+L<Dist::Zilla::Role::PluginBundle::Config::Slicer> so I can remove or
+configure any plugin as needed.
+
+This is more or less equivalent to the following F<dist.ini>:
+
+    ; Picks one of these - defaults to MakeMaker
+    [MakeMaker]
+    [ModuleBuild]
+
+    [Git::GatherDir]
+    ; Both are configured by setting exclude_files for the bundle. Simple
+    ; values like "./foo/bar.pl" are treated as filenames, others like
+    ; "*\.jnk$" are treated as a regex.
+    exclude_filenames = ...
+    exclude_match     = ...
+
+    [ManifestSkip]
+    [License]
+    [ExecDir]
+    [ShareDir]
+    [Manifest]
+    [CheckVersionIncrement]
+    [TestRelease]
+    [ConfirmRelease]
+    [UploadToCPAN]
+    ; Opens up the main module and finds a $VERSION
+    [DROLSKY::VersionProvider]
+
+    [Authority]
+    ; Configured by setting authority for the bundle
+    authority  = ...
+    do_munging = 0
+
+    [AutoPrereqs]
+    ; Configured by setting skip_prereqs for the bundle
+    skip = ...
+
+    [CopyFilesFromBuild]
+    copy = Build.PL
+    copy = CONTRIBUTING.md
+    copy = LICENSE
+    copy = Makefile.PL
+    copy = README.md
+    copy = cpanfile
+    copy = ppport.h
+
+    [GitHub::Meta]
+    ; Configured by setting use_github_issues for the bundle
+    bugs = 0
+    ; Configured by setting use_github_homepage for the bundle
+    homepage = 0
+
+    [MetaResources]
+    homepage = http://metacpan.org/release/My-Module
+    ; RT bits are omitted if use_github_issue is true
+    bugtracker.web  = http://rt.cpan.org/Public/Dist/Display.html?Name=My-Module
+    bugtracker.mail = bug-My-Module@rt.cpan.org
+
+    [MetaProvides::Pckage]
+    meta_noindex = 1
+
+    [Meta::Contributors]
+    [Meta::Config]
+    [MetaJSON]
+    [MetaYAML]
+
+    [NextRelease]
+    ; Width is configured by setting next_release_width for the bundle
+    format = %-8v %{yyyy-MM-dd}d%{ (TRIAL RELEASE)}T
+
+    ; Scans the test files for use of Test2 and picks either
+    [Prereqs / Test::More with Test2]
+    -phase = test
+    -type  = requires
+    Test::More = 1.302015
+
+    ; If the distro doesn't use Test2
+    [Prereqs / Test::More with subtest]
+    -phase = test
+    -type  = requires
+    Test::More = 0.96
+
+    [Prereqs / Modules for use with tidyall]
+    -phase = develop
+    -type  = requires
+    Code::TidyAll::Plugin::Test::Vars = 0.02
+    Perl::Critic                      = 1.126
+    Perl::Tidy                        = 20160302
+    Test::Vars                        = 0.009
+
+    [Prereqs / Test::Version which fixes https://github.com/plicease/Test-Version/issues/7]
+    -phase = develop
+    -type  = requires
+    Test::Version = 2.05
+
+    [PromptIfStale]
+    phase  = build
+    module = Dist::Zilla::PluginBundle::DROLSKY
+
+    [PromptIfStale]
+    phase = release
+    check_all_plugins = 1
+    check_all_prereqs = 1
+    check_authordeps  = 1
+    skip = Dist::Zilla::Plugin::DROLSKY::CheckChangesHasContent
+    skip = Dist::Zilla::Plugin::DROLSKY::Contributors
+    skip = Dist::Zilla::Plugin::DROLSKY::Git::CheckFor::CorrectBranch
+    skip = Dist::Zilla::Plugin::DROLSKY::License
+    skip = Dist::Zilla::Plugin::DROLSKY::TidyAll
+    skip = Dist::Zilla::Plugin::DROLSKY::VersionProvider
+    skip = Pod::Weaver::PluginBundle::DROLSKY
+
+    [Test::Pod::Coverage::Configurable]
+    ; Configured by setting pod_coverage_class for the bundle
+    class = ...
+    ; Configured by setting pod_coverage_skip for the bundle
+    skip = ...
+    ; Configured by setting pod_coverage_trustme for the bundle
+    trustme = ...
+
+    [Test::PodSpelling]
+    ; Configured by setting stopwords and/or stopwords_file for the bundle
+    stopwods = ...
+
+    [PodSyntaxTests]
+
+    [RunExtraTests]
+    [MojibakeTests]
+    [Test::CleanNamespaces]
+    [Test::CPAN::Changes]
+    [Test::CPAN::Meta::JSON]
+    [Test::EOL]
+    [Test::NoTabs]
+    [Test::Portability]
+    [Test::Synopsis]
+
+    [Test::TidyAll]
+    verbose = 1
+    minimum_perl = 5.010
+
+    [Test::Compile]
+    xt_mode = 1
+
+    [Test::ReportPrereqs]
+    verify_prereqs = 1
+
+    [Test::Version]
+    is_strict = 1
+
+    ; Generates/updates a .mailmap file
+    [DROLSKY::Contributors]
+    [Git::Contributors]
+
+    [SurgicalPodWeaver]
+    ; See Pod::Weaver::PluginBundle::DROLSKY in this same distro for more info
+    config_plugin = @DROLSKY
+
+    ; Nasty hack so I can pass config from the dist.ini to the Pod::Weaver
+    ; bundle. Currently used so I can set
+    ; "DROLSKY::WeaverConfig.include_donations_pod = 0" in a dist.ini file.
+    [DROLSKY::WeaverConfig]
+
+    [ReadmeAnyFromPod / README.md in build]
+    type     = markdown
+    filename = README.md
+    location = build
+    phase    = build
+
+    [GenerateFile::FromShareDir / Generate CONTRIBUTING.md]
+    -dist     = Dist-Zilla-PluginBundle-DROLSKY
+    -filename = CONTRIBUTING.md
+    ; This is determined by looking through the distro for .xs files.
+    has_xs    = ...
+
+    [InstallGuide]
+    [CPANFile]
+
+    ; Only added if the distro has .xs files
+    [PPPort]
+
+    ; Like the default License plugin except that it defaults to Artistic 2.0.
+    ; Also, if the copyright_year for the bundle is not this year, it passes
+    ; something like "2014-2016" to Software::License.
+    [DROLSKY::License]
+
+    [CheckPrereqsIndexed]
+
+    ; More or less like Dist::Zilla::Plugin::CheckChangesHasContent but uses
+    ; CPAN::Changes to parse the Changes file.
+    [DROLSKY::CheckChangesHasContent]
+
+    ; Just like Dist::Zilla::Plugin::Git::CheckFor::CorrectBranch except that
+    ; it allows releases from any branch for TRIAL
+    ; releases. https://github.com/RsrchBoy/dist-zilla-pluginbundle-git-checkfor/issues/24
+    [DROLSKY::Git::CheckFor::CorrectBranch]
+
+    [Git::CheckFor::MergeConflicts]
+
+    ; Generates/updates tidyall.ini, perlcriticrc, and perltidyrc
+    [DROLSKY::TidyAll]
+
+    ; The allow_dirty list is basically all of the generated or munged files
+    ; in the distro, including:
+    ;     Build.PL
+    ;     CONTRIBUTING.md
+    ;     Changes
+    ;     LICENSE
+    ;     Makefile.PL
+    ;     README.md
+    ;     cpanfile
+    ;     ppport.h
+    ;     tidyall.ini
+    [Git::Check]
+    allow_dirty = ...
+
+    [Git::Commit / Commit generated files]
+    allow_dirty = ...
+
+    [Git::Tag]
+    [Git::Push]
+
+    [BumpVersionAfterRelease]
+
+    [Git::Commit / Commit version bump]
+    allow_dirty_match = .+
+    commit_msg        = Bump version after release
+
+    [Git::Push / Push version bump]
+
 =for Pod::Coverage .*
 
 =head1 SUPPORT
