@@ -3,7 +3,7 @@ package Pod::Weaver::PluginBundle::DROLSKY;
 use strict;
 use warnings;
 
-our $VERSION = '0.70';
+our $VERSION = '0.71';
 
 use namespace::autoclean -also => ['_exp'];
 
@@ -239,7 +239,7 @@ Pod::Weaver::PluginBundle::DROLSKY - A plugin bundle for pod woven by DROLSKY
 
 =head1 VERSION
 
-version 0.70
+version 0.71
 
 =head1 SYNOPSIS
 
@@ -311,6 +311,8 @@ following F<weaver.ini>, minus some optimizations:
     action = prepend
     match_anywhere = 0
 
+    ; Can be disabled in dist.ini with
+    ;   DROLSKY::WeaverConfig.include_donations_pod = 0
     [GenerateSection / generate DONATIONS]
     title = DONATIONS
     main_module_only = 1
